@@ -18,6 +18,9 @@ use crate::types::{
 use crate::{driver::CANAerospaceDriver, types::MessageType};
 
 pub mod driver;
+#[cfg(not(tarpaulin_include))]
+#[cfg(feature = "ids-standard")]
+pub mod id_distribution;
 pub mod message;
 mod tests;
 pub mod types;
@@ -28,6 +31,10 @@ pub mod types;
 // #[doc(cfg(feature = "bxcan-support"))]
 pub mod bxcan;
 
+#[cfg(not(tarpaulin_include))]
+#[cfg(feature = "ids-standard")]
+pub use id_distribution as ids;
+
 pub const IDS_CONF_STANDARD: IDSConfiguration = IDSConfiguration(0);
 pub const IDS_MSG_HEADER_STANDARD: IDSHeaderConfiguration = 0;
 
